==> haskell-unliftio-0.2.25.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unliftio
version:              0.2.25.1
visibility:           public
id:                   unliftio-0.2.25.1-8YwSA5F3PHp2BbuK70PMTe
key:                  unliftio-0.2.25.1-8YwSA5F3PHp2BbuK70PMTe
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  e153af9c062bf79361f2bd05442e910c
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Exception.Lens UnliftIO.Foreign UnliftIO.IO
    UnliftIO.IO.File UnliftIO.IORef UnliftIO.Internals.Async
    UnliftIO.MVar UnliftIO.Memoize UnliftIO.Process UnliftIO.QSem
    UnliftIO.QSemN UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio
hs-libraries:         HSunliftio-0.2.25.1-8YwSA5F3PHp2BbuK70PMTe
depends:
    async-2.2.5-JRkOlssciRvEYBeGTRPtJy base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0
    safe-exceptions-0.1.7.4-BBKDsAtRpBH6qLrhSKc3Xx stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.25.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unliftio
version:              0.2.25.1
visibility:           public
id:                   unliftio-0.2.25.1-DyweKXwNyOA6bCdvyvzfdZ
key:                  unliftio-0.2.25.1-DyweKXwNyOA6bCdvyvzfdZ
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  a049954f754530fe55871c9f2204b079
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Exception.Lens UnliftIO.Foreign UnliftIO.IO
    UnliftIO.IO.File UnliftIO.IORef UnliftIO.Internals.Async
    UnliftIO.MVar UnliftIO.Memoize UnliftIO.Process UnliftIO.QSem
    UnliftIO.QSemN UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unliftio-0.2.25.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio
hs-libraries:         HSunliftio-0.2.25.1-DyweKXwNyOA6bCdvyvzfdZ
depends:
    async-2.2.5-9QaZZ5mvSnsGaP8eWFDbSX base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0
    safe-exceptions-0.1.7.4-FtKVhTVyXySJeE4rRBYWkc stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
